@@ -1605,7 +1605,7 @@ e_mapi_config_utils_insert_widgets (ESourceConfigBackend *backend,
 	e_source_config_insert_widget (config, scratch_source, NULL, widget);
 	gtk_widget_show (widget);
 
-	g_object_bind_property (
+	e_binding_bind_property (
 		folder_ext, "server-notification",
 		widget, "active",
 		G_BINDING_BIDIRECTIONAL |
